@@ -95,14 +95,13 @@ def _format_sql_cell(
     if NOFMT in cell.strip().splitlines()[0]:
         return title_line + cell
 
-    magics = []
     sql_lines = []
-    for line in cell.strip().splitlines():
-        if line.strip().startswith("# MAGIC %sql"):
+    for line in (line.strip() for line in cell.strip().splitlines()):
+        if line == "# MAGIC %sql":
             continue
-        words = line.split()
-        magic, sql = words[:2], words[2:]
-        magics.append(magic)
+        elif line.startswith("# MAGIC %sql"):
+            line = line.replace(" %sql", "", 1)
+        sql = line.split()[2:]  # Remove "# MAGIC".
         sql_lines.append(" ".join(sql).strip())
 
     return (
@@ -111,7 +110,9 @@ def _format_sql_cell(
         + "\n".join(
             f"# MAGIC {sql}"
             for sql in sqlparse.format(
-                "\n".join(sql_lines), reindent=True, keyword_case=sql_keyword_case
+                "\n".join(sql_lines).strip(),
+                reindent=True,
+                keyword_case=sql_keyword_case,
             ).splitlines()
         )
     )
